@@ -17,7 +17,8 @@ def console_main():
     if data_tests:
         data_before_after = dict(sorted(data_before_after.items(), key=lambda x: x[0]))
         requests = Api(reader.get_url(), reader.get_privatetoken())
-        tests_results_data = []
+
+        testrun_id = requests.create_testrun(JSONFixture.create_testrun(reader.get_project_id(), f'AllureRun {datetime.today().strftime("%d %b %Y %H:%M:%S")}'))
 
         for history_id in data_tests:
             prefix = '' if 'uuid' in data_tests[history_id] else '@'
@@ -101,8 +102,9 @@ def console_main():
             for workitem_id in workitems_id:
                 requests.link_autotest(autotest_id, workitem_id)
 
-            tests_results_data.append(
-                JSONFixture.set_results_for_testrun(
+            requests.set_results_for_testrun(
+                testrun_id,
+                [JSONFixture.set_results_for_testrun(
                     history_id,
                     reader.get_configuration_id(),
                     outcome,
@@ -119,15 +121,7 @@ def console_main():
                     None,
                     data_tests[history_id]['statusDetails']['message'] if
                         'statusDetails' in data_tests[history_id] and data_tests[history_id]['statusDetails'] and 'message' in data_tests[history_id]['statusDetails'] else None
-                )
-            )
-
-        testrun_id = requests.create_testrun(JSONFixture.create_testrun(reader.get_project_id(), f'AllureRun {datetime.today().strftime("%d %b %Y %H:%M:%S")}'))
-
-        if tests_results_data:
-            requests.set_results_for_testrun(
-                testrun_id,
-                tests_results_data
+                )]
             )
 
 
