@@ -130,7 +130,10 @@ def get_attachment(requests, attachments_sources, path):
         prefix = '' if 'source' in attachments_sources[0] else '@'
 
         for attachment_source in attachments_sources:
-            attachments.append({'id': requests.load_attachment(open(f"{path}/{attachment_source[f'{prefix}source']}", 'rb'))})
+            attachment_id = requests.load_attachment(open(f"{path}/{attachment_source[f'{prefix}source']}", 'rb'))
+
+            if attachment_id:
+                attachments.append({'id': attachment_id})
 
     return attachments
 
